@@ -3,7 +3,7 @@
             [com.puppetlabs.puppetdb.reports :as report]
             [clojure.string :as string])
   (:use [com.puppetlabs.concurrent :only (bounded-pmap)]
-        [com.puppetlabs.utils :only (regexp? boolean? uuid string-contains?)]
+        [puppetlabs.kitchensink.core :only (regexp? boolean? uuid string-contains?)]
         [clojure.walk :only (keywordize-keys)]
         [com.puppetlabs.random]))
 
@@ -74,7 +74,7 @@
   [pattern]
   {:pre [(string? pattern) (pattern-string? pattern)]
    :post [(regexp? %)]}
-  (re-pattern (.substring pattern 1 (- (count pattern) 1))))
+  (re-pattern (.substring pattern 1 (dec (count pattern)))))
 
 (defn matcher-match?
   "Compares a rule matcher against a value, returning true if it's a match."
