@@ -8,13 +8,12 @@
 ;; database.
 
 (ns com.puppetlabs.puppetdb.cli.export
-  (:use [com.puppetlabs.utils :only (cli!)]
+  (:use [puppetlabs.kitchensink.core :only (cli!)]
         [clj-time.core :only [now]]
-        [clj-time.coerce :only [to-string]]
         [com.puppetlabs.concurrent :only [bounded-pmap]]
         [clj-http.util :only [url-encode]]
         [com.puppetlabs.puppetdb.catalogs :only [catalog-version]])
-  (:require [cheshire.core :as json]
+  (:require [com.puppetlabs.cheshire :as json]
             [fs.core :as fs]
             [clojure.java.io :as io]
             [clj-http.client :as client]
@@ -55,7 +54,7 @@
       (sort-by
         #(mapv % [:timestamp :resource-type :resource-title :property])
         (map
-          #(dissoc % :report :certname :configuration-version :containing-class)
+          #(dissoc % :report :certname :configuration-version :containing-class :run-start-time :run-end-time :report-receive-time)
           (json/parse-string body true))))))
 
 (defn reports-for-node
@@ -94,7 +93,7 @@
 
 (def export-metadata
   "Metadata about this export; used during import to ensure version compatibility."
-  {:timestamp (to-string (now))
+  {:timestamp (now)
    :command-versions
     ;; This is not ideal that we are hard-coding the command version here, but
     ;;  in our current architecture I don't believe there is any way to introspect
@@ -141,7 +140,7 @@
   [& args]
   (let [specs          [["-o" "--outfile" "Path to backup file (required)"]
                         ["-H" "--host" "Hostname of PuppetDB server" :default "localhost"]
-                        ["-p" "--port" "Port to connect to PuppetDB server" :parse-fn #(Integer. %) :default 8080]]
+                        ["-p" "--port" "Port to connect to PuppetDB server (HTTP protocol only)" :parse-fn #(Integer. %) :default 8080]]
         required       [:outfile]
         [{:keys [outfile host port]} _] (cli! args specs required)
         nodes          (get-active-node-names host port)
