@@ -8,7 +8,7 @@
 (defn get-fact-names
   "Produces a response body containing the list of known facts."
   [{:keys [globals]}]
-  (let [db (:scf-db globals)
+  (let [db (:scf-read-db globals)
         facts (with-transacted-connection db
                 (f/fact-names))]
     (pl-http/json-response (:result facts))))
