@@ -5,9 +5,9 @@
 ;; right format and picking out the desired columns.
 ;;
 (ns com.puppetlabs.puppetdb.query.resources
-  (:require [cheshire.core :as json]
+  (:require [com.puppetlabs.cheshire :as json]
             [clojure.string :as string]
-            [com.puppetlabs.utils :as utils])
+            [puppetlabs.kitchensink.core :as kitchensink])
   (:use [com.puppetlabs.jdbc :only [limited-query-to-vec
                                     convert-result-arrays
                                     with-transacted-connection
@@ -15,7 +15,8 @@
                                     valid-jdbc-query?
                                     get-result-count
                                     paged-sql
-                                    count-sql]]
+                                    count-sql
+                                    with-query-results-cursor]]
         [com.puppetlabs.puppetdb.query :only [resource-query->sql
                                               resource-operators-v1
                                               resource-operators-v2
@@ -43,21 +44,22 @@
              (valid-jdbc-query? (:count-query %)))]}
     (validate-order-by! (map keyword (keys resource-columns)) paging-options)
     (let [[subselect & params] (resource-query->sql operators query)
-          paged-subselect      (paged-sql subselect paging-options)
-          sql                  (format "SELECT subquery1.certname, subquery1.resource,
-                                               subquery1.type, subquery1.title, subquery1.tags,
-                                               subquery1.exported, subquery1.file,
-                                               subquery1.line, rp.name, rp.value
-                                        FROM (%s) subquery1
-                                        LEFT OUTER JOIN resource_params rp ON rp.resource = subquery1.resource"
-                                 paged-subselect)
+          sql (format (str "SELECT subquery1.certname, subquery1.resource, "
+                                  "subquery1.type, subquery1.title, subquery1.tags, "
+                                  "subquery1.exported, subquery1.file, "
+                                  "subquery1.line, rpc.parameters "
+                            "FROM (%s) subquery1 "
+                            "LEFT OUTER JOIN resource_params_cache rpc "
+                                "ON rpc.resource = subquery1.resource")
+                subselect)
+          paged-select (paged-sql sql paging-options)
           ;; This is a little more complex than I'd prefer; the general query paging
           ;;  functions are built to work for SQL queries that return 1 row per
           ;;  PuppetDB result.  Since that's not the case for resources right now,
           ;;  we have to actually manage two separate SQL queries.  The introduction
           ;;  of the new `resource-params-cache` table in the next release should
           ;;  alleviate this problem and allow us to simplify this code.
-          result               {:results-query (apply vector sql params)}]
+          result               {:results-query (apply vector paged-select params)}]
       (if (:count? paging-options)
         (assoc result :count-query (apply vector (count-sql subselect) params))
         result))))
@@ -71,38 +73,20 @@
 (def v3-query->sql
   (partial query->sql resource-operators-v3))
 
-(defn- consolidate-resource-params
-  "Given the raw query results from the database, consolidate all the resource
-  parameters for each resource and put them into a hash on each resource keyed
-  at `:parameters`."
-  [query-results]
-  (let [metadata_cols [:certname :resource :type :title :tags :exported :file :line]
-        metadata      (apply juxt metadata_cols)
-        groupings     (group-by metadata query-results)]
-    (vec (for [[resource params] groupings]
-           (assoc (zipmap metadata_cols resource)
-                  :parameters
-                  (into {} (for [param params :when (:name param)]
-                             [(:name param) (json/parse-string (:value param))])))))))
+(defn deserialize-params
+  [resources]
+  (let [parse-params #(if % (json/parse-string %) {})]
+    (map #(update-in % [:parameters] parse-params) resources)))
 
-(defn- post-process-results
-  "Given the results of the query and the optional order-by paging clauses,
-  consolidate the results into a form appropriate for returning to the user
-  and sort them based on the order-by clauses, if there are any."
-  [query-results order-bys]
-  {:pre  [(vector? query-results)
-          ((some-fn nil? sequential?) order-bys)
-          (every? utils/order-by-expr? order-bys)]
-   :post [(vector? %)]}
-  (let [consolidated-results (consolidate-resource-params query-results)]
-    (if (empty? order-bys)
-      consolidated-results
-      (vec (utils/order-by order-bys consolidated-results)))))
+(defn with-queried-resources
+  [query params func]
+  (let [parse-params #(if % (json/parse-string %) {})]
+    (with-query-results-cursor query params rs
+      (func (deserialize-params rs)))))
 
 (defn limited-query-resources
-  "Take a limit, a map of paging options, and a map of SQL queries as
-  produced by `query->sql`, return a map containing the results of the
-  query, as well as optional metadata.
+  "Take a limit, and a map of SQL queries as produced by `query->sql`, return
+  a map containing the results of the query, as well as optional metadata.
 
   The returned map will contain a key `:result`, whose value is vector of
   resources which match the query.  If the paging-options used to generate
@@ -111,21 +95,18 @@
 
    Throws an exception if the query would return more than `limit` results.  (A
    value of `0` for `limit` means that the query should not be limited.)"
-  ([limit queries-map]
-    (limited-query-resources limit {} queries-map))
-  ([limit paging-options {:keys [results-query count-query] :as queries-map}]
-    {:pre  [(and (integer? limit) (>= limit 0))]
-     :post [(or (zero? limit) (<= (count %) limit))]}
-    (let [[query & params] results-query
-          limited-query (add-limit-clause limit query)
-          query-results (limited-query-to-vec limit (apply vector limited-query params))
-          results       {:result
-                          (post-process-results
-                            query-results
-                            (:order-by paging-options))}]
-      (if count-query
-        (assoc results :count (get-result-count count-query))
-        results))))
+  [limit {:keys [results-query count-query] :as queries-map}]
+  {:pre  [(and (integer? limit) (>= limit 0))]
+   :post [(or (zero? limit) (<= (count %) limit))]}
+  (let [[query & params] results-query
+        limited-query (add-limit-clause limit query)
+        results       (limited-query-to-vec limit (apply vector limited-query params))
+        metadata_cols [:certname :resource :type :title :tags :exported :file :line]
+        metadata      (apply juxt metadata_cols)
+        results       {:result (deserialize-params results)}]
+    (if count-query
+      (assoc results :count (get-result-count count-query))
+      results)))
 
 (defn query-resources
   "Takes a map of SQL queries as produced by `query->sql`, and returns a map
